@@ -86,7 +86,8 @@ ProjectSourcePage::ProjectSourcePage(const QUrl& initial, const QUrl& repoUrl, I
     // during setup and due to a bug will ignore any but the first call
     // Only fixed for KF5 5.32
     connect(m_ui->workingDir, &KUrlRequester::textChanged, this, &ProjectSourcePage::reevaluateCorrection);
-    connect(m_ui->sources, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ProjectSourcePage::setSourceIndex);
+    connect(m_ui->sources, QOverload<int>::of(&QComboBox::currentIndexChanged),
+            this, &ProjectSourcePage::setSourceIndex);
     connect(m_ui->get, &QPushButton::clicked, this, &ProjectSourcePage::checkoutVcsProject);
 }
 
@@ -166,7 +167,7 @@ VcsJob* ProjectSourcePage::jobPerCurrent()
     IPlugin* p=m_plugins[m_ui->sources->currentIndex()];
     VcsJob* job=nullptr;
 
-    if(IBasicVersionControl* iface=p->extension<IBasicVersionControl>()) {
+    if(auto* iface=p->extension<IBasicVersionControl>()) {
         Q_ASSERT(iface && m_locationWidget);
         job=iface->createWorkingCopy(m_locationWidget->location(), url);
     } else if(m_providerWidget) {
