@@ -1,6 +1,7 @@
 /***************************************************************************
  *   Copyright 2008 Andreas Pakulat <apaku@gmx.de>                         *
  *   Copyright 2010 Aleix Pol Gonzalez <aleixpol@kde.org>                  *
+ *   Copyright 2017-2018 Friedrich W. H. Kossebau <kossebau@kde.org>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -28,6 +29,7 @@
 #include <KTextEditor/Document>
 #include <KTextEditor/ModificationInterface>
 #include <KTextEditor/View>
+#include <ktexteditor_version.h>
 
 #include <interfaces/context.h>
 #include <interfaces/contextmenuextension.h>
@@ -45,6 +47,9 @@
 #include <util/scopeddialog.h>
 #include <vcs/interfaces/ibasicversioncontrol.h>
 #include <vcs/models/vcsannotationmodel.h>
+#if KTEXTEDITOR_VERSION >= QT_VERSION_CHECK(5,53,0)
+#include <vcs/widgets/vcsannotationitemdelegate.h>
+#endif
 #include <vcs/widgets/vcseventwidget.h>
 #include <vcs/widgets/vcscommitdialog.h>
 #include <vcs/vcsjob.h>
@@ -99,7 +104,7 @@ public:
         QObject::connect(revertAction, &QAction::triggered, parent, &VcsPluginHelper::revert);
         QObject::connect(historyAction, &QAction::triggered, parent, [=] { parent->history(); });
         QObject::connect(annotationAction, &QAction::triggered, parent, &VcsPluginHelper::annotation);
-        QObject::connect(diffForRevAction, &QAction::triggered, parent, static_cast<void(VcsPluginHelper::*)()>(&VcsPluginHelper::diffForRev));
+        QObject::connect(diffForRevAction, &QAction::triggered, parent, QOverload<>::of(&VcsPluginHelper::diffForRev));
         QObject::connect(diffForRevGlobalAction, &QAction::triggered, parent, &VcsPluginHelper::diffForRevGlobal);
         QObject::connect(pullAction, &QAction::triggered, parent, &VcsPluginHelper::pull);
         QObject::connect(pushAction, &QAction::triggered, parent, &VcsPluginHelper::push);
@@ -118,7 +123,7 @@ public:
     QMenu* createMenu(QWidget* parent)
     {
         bool allVersioned=true;
-        foreach(const QUrl &url, ctxUrls) {
+        for (const QUrl& url : qAsConst(ctxUrls)) {
             allVersioned=allVersioned && vcs->isVersionControlled(url);
 
             if(!allVersioned)
@@ -155,8 +160,10 @@ public:
 
 VcsPluginHelper::VcsPluginHelper(KDevelop::IPlugin* parent, KDevelop::IBasicVersionControl* vcs)
         : QObject(parent)
-        , d(new VcsPluginHelperPrivate())
+        , d_ptr(new VcsPluginHelperPrivate())
 {
+    Q_D(VcsPluginHelper);
+
     Q_ASSERT(vcs);
     Q_ASSERT(parent);
     d->plugin = parent;
@@ -169,6 +176,8 @@ VcsPluginHelper::~VcsPluginHelper()
 
 void VcsPluginHelper::addContextDocument(const QUrl &url)
 {
+    Q_D(VcsPluginHelper);
+
     d->ctxUrls.append(url);
 }
 
@@ -186,16 +195,22 @@ void VcsPluginHelper::disposeEventually(KTextEditor::Document *)
 
 void VcsPluginHelper::setupFromContext(Context* context)
 {
+    Q_D(VcsPluginHelper);
+
     d->ctxUrls = context->urls();
 }
 
 QList<QUrl> VcsPluginHelper::contextUrlList() const
 {
+    Q_D(const VcsPluginHelper);
+
     return d->ctxUrls;
 }
 
 QMenu* VcsPluginHelper::commonActions(QWidget* parent)
 {
+    Q_D(VcsPluginHelper);
+
     /* TODO: the following logic to determine which actions need to be enabled
      * or disabled does not work properly. What needs to be implemented is that
      * project items that are vc-controlled enable all except add, project
@@ -218,14 +233,16 @@ QMenu* VcsPluginHelper::commonActions(QWidget* parent)
 
 void VcsPluginHelper::revert()
 {
+    Q_D(VcsPluginHelper);
+
     VcsJob* job=d->vcs->revert(d->ctxUrls);
     connect(job, &VcsJob::finished, this, &VcsPluginHelper::revertDone);
 
-    foreach(const QUrl &url, d->ctxUrls) {
+    for (const QUrl& url : qAsConst(d->ctxUrls)) {
         IDocument* doc=ICore::self()->documentController()->documentForUrl(url);
 
         if(doc && doc->textDocument()) {
-            KTextEditor::ModificationInterface* modif = dynamic_cast<KTextEditor::ModificationInterface*>(doc->textDocument());
+            auto* modif = qobject_cast<KTextEditor::ModificationInterface*>(doc->textDocument());
             if (modif) {
                 modif->setModifiedOnDiskWarning(false);
             }
@@ -239,7 +256,7 @@ void VcsPluginHelper::revert()
 
 void VcsPluginHelper::revertDone(KJob* job)
 {
-    QTimer* modificationTimer = new QTimer;
+    auto* modificationTimer = new QTimer;
     modificationTimer->setInterval(100);
     connect(modificationTimer, &QTimer::timeout, this, &VcsPluginHelper::delayedModificationWarningOn);
     connect(modificationTimer, &QTimer::timeout, modificationTimer, &QTimer::deleteLater);
@@ -260,7 +277,7 @@ void VcsPluginHelper::delayedModificationWarningOn()
         if(doc) {
             doc->reload();
 
-            KTextEditor::ModificationInterface* modif=dynamic_cast<KTextEditor::ModificationInterface*>(doc->textDocument());
+            auto* modif = qobject_cast<KTextEditor::ModificationInterface*>(doc->textDocument());
             modif->setModifiedOnDiskWarning(true);
         }
     }
@@ -269,7 +286,7 @@ void VcsPluginHelper::delayedModificationWarningOn()
 
 void VcsPluginHelper::diffJobFinished(KJob* job)
 {
-    KDevelop::VcsJob* vcsjob = qobject_cast<KDevelop::VcsJob*>(job);
+    auto* vcsjob = qobject_cast<KDevelop::VcsJob*>(job);
     Q_ASSERT(vcsjob);
 
     if (vcsjob->status() == KDevelop::VcsJob::JobSucceeded) {
@@ -279,7 +296,7 @@ void VcsPluginHelper::diffJobFinished(KJob* job)
                                      i18n("There are no differences."),
                                      i18n("VCS support"));
         else {
-            VCSDiffPatchSource* patch=new VCSDiffPatchSource(d);
+            auto* patch=new VCSDiffPatchSource(d);
             showVcsDiff(patch);
         }
     } else {
@@ -289,15 +306,19 @@ void VcsPluginHelper::diffJobFinished(KJob* job)
 
 void VcsPluginHelper::diffToBase()
 {
+    Q_D(VcsPluginHelper);
+
     SINGLEURL_SETUP_VARS
     ICore::self()->documentController()->saveAllDocuments();
 
-    VCSDiffPatchSource* patch =new VCSDiffPatchSource(new VCSStandardDiffUpdater(iface, url));
+    auto* patch =new VCSDiffPatchSource(new VCSStandardDiffUpdater(iface, url));
     showVcsDiff(patch);
 }
 
 void VcsPluginHelper::diffForRev()
 {
+    Q_D(VcsPluginHelper);
+
     if (d->ctxUrls.isEmpty()) {
         return;
     }
@@ -306,6 +327,8 @@ void VcsPluginHelper::diffForRev()
 
 void VcsPluginHelper::diffForRevGlobal()
 {
+    Q_D(VcsPluginHelper);
+
     if (d->ctxUrls.isEmpty()) {
         return;
     }
@@ -320,7 +343,9 @@ void VcsPluginHelper::diffForRevGlobal()
 
 void VcsPluginHelper::diffForRev(const QUrl& url)
 {
-    QAction* action = qobject_cast<QAction*>( sender() );
+    Q_D(VcsPluginHelper);
+
+    auto* action = qobject_cast<QAction*>( sender() );
     Q_ASSERT(action);
     Q_ASSERT(action->data().canConvert<VcsRevision>());
     VcsRevision rev = action->data().value<VcsRevision>();
@@ -335,15 +360,17 @@ void VcsPluginHelper::diffForRev(const QUrl& url)
 
 void VcsPluginHelper::history(const VcsRevision& rev)
 {
+    Q_D(VcsPluginHelper);
+
     SINGLEURL_SETUP_VARS
     QDialog* dlg = new QDialog(ICore::self()->uiController()->activeMainWindow());
     dlg->setAttribute(Qt::WA_DeleteOnClose);
     dlg->setWindowTitle(i18nc("%1: path or URL, %2: name of a version control system",
                           "%2 History (%1)", url.toDisplayString(QUrl::PreferLocalFile), iface->name()));
 
-    QVBoxLayout *mainLayout = new QVBoxLayout(dlg);
+    auto *mainLayout = new QVBoxLayout(dlg);
 
-    KDevelop::VcsEventWidget* logWidget = new KDevelop::VcsEventWidget(url, rev, iface, dlg);
+    auto* logWidget = new KDevelop::VcsEventWidget(url, rev, iface, dlg);
     mainLayout->addWidget(logWidget);
 
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
@@ -356,14 +383,17 @@ void VcsPluginHelper::history(const VcsRevision& rev)
 
 void VcsPluginHelper::annotation()
 {
+    Q_D(VcsPluginHelper);
+
     SINGLEURL_SETUP_VARS
     KDevelop::IDocument* doc = ICore::self()->documentController()->documentForUrl(url);
 
     if (!doc)
         doc = ICore::self()->documentController()->openDocument(url);
 
+    KTextEditor::View* view = doc ? doc->activeTextView() : nullptr;
     KTextEditor::AnnotationInterface* annotateiface = qobject_cast<KTextEditor::AnnotationInterface*>(doc->textDocument());
-    KTextEditor::AnnotationViewInterface* viewiface = qobject_cast<KTextEditor::AnnotationViewInterface*>(doc->activeTextView());
+    auto viewiface = qobject_cast<KTextEditor::AnnotationViewInterface*>(view);
     if (viewiface && viewiface->isAnnotationBorderVisible()) {
         viewiface->setAnnotationBorderVisible(false);
         return;
@@ -379,7 +409,7 @@ void VcsPluginHelper::annotation()
 
         QColor foreground(Qt::black);
         QColor background(Qt::white);
-        if (KTextEditor::View* view = doc->activeTextView()) {
+        if (view) {
             KTextEditor::Attribute::Ptr style = view->defaultStyleAttribute(KTextEditor::dsNormal);
             foreground = style->foreground().color();
             if (style->hasProperty(QTextFormat::BackgroundBrush)) {
@@ -389,15 +419,24 @@ void VcsPluginHelper::annotation()
 
         if (annotateiface && viewiface) {
             // TODO: only create model if there is none yet (e.g. from another view)
-            KDevelop::VcsAnnotationModel* model = new KDevelop::VcsAnnotationModel(job, url, doc->textDocument(),
+            auto* model = new KDevelop::VcsAnnotationModel(job, url, doc->textDocument(),
                                                                                    foreground, background);
             annotateiface->setAnnotationModel(model);
+
+#if KTEXTEDITOR_VERSION >= QT_VERSION_CHECK(5,53,0)
+            auto viewifaceV2 = qobject_cast<KTextEditor::AnnotationViewInterfaceV2*>(view);
+            if (viewifaceV2) {
+                // TODO: only create delegate if there is none yet
+                auto delegate = new VcsAnnotationItemDelegate(view, model, view);
+                viewifaceV2->setAnnotationItemDelegate(delegate);
+                viewifaceV2->setAnnotationUniformItemSizes(true);
+            }
+#endif
             viewiface->setAnnotationBorderVisible(true);
             // can't use new signal slot syntax here, AnnotationInterface is not a QObject
-            connect(doc->activeTextView(),
-                    SIGNAL(annotationContextMenuAboutToShow(KTextEditor::View*,QMenu*,int)),
+            connect(view, SIGNAL(annotationContextMenuAboutToShow(KTextEditor::View*,QMenu*,int)),
                     this, SLOT(annotationContextMenuAboutToShow(KTextEditor::View*,QMenu*,int)));
-            connect(doc->activeTextView(), SIGNAL(annotationBorderVisibilityChanged(View*,bool)),
+            connect(view, SIGNAL(annotationBorderVisibilityChanged(View*,bool)),
                     this, SLOT(handleAnnotationBorderVisibilityChanged(View*,bool)));
         } else {
             KMessageBox::error(nullptr, i18n("Cannot display annotations, missing interface KTextEditor::AnnotationInterface for the editor."));
@@ -411,10 +450,19 @@ void VcsPluginHelper::annotation()
 
 void VcsPluginHelper::annotationContextMenuAboutToShow( KTextEditor::View* view, QMenu* menu, int line )
 {
+    Q_D(VcsPluginHelper);
+
+#if KTEXTEDITOR_VERSION >= QT_VERSION_CHECK(5,53,0)
+    auto viewifaceV2 = qobject_cast<KTextEditor::AnnotationViewInterfaceV2*>(view);
+    if (viewifaceV2) {
+        viewifaceV2->annotationItemDelegate()->hideTooltip(view);
+    }
+#endif
+
     KTextEditor::AnnotationInterface* annotateiface =
         qobject_cast<KTextEditor::AnnotationInterface*>(view->document());
 
-    VcsAnnotationModel* model = qobject_cast<VcsAnnotationModel*>( annotateiface->annotationModel() );
+    auto* model = qobject_cast<VcsAnnotationModel*>( annotateiface->annotationModel() );
     Q_ASSERT(model);
 
     VcsRevision rev = model->revisionForLine(line);
@@ -458,23 +506,29 @@ void VcsPluginHelper::handleAnnotationBorderVisibilityChanged(View* view, bool v
 
 void VcsPluginHelper::update()
 {
+    Q_D(VcsPluginHelper);
+
     EXECUTE_VCS_METHOD(update);
 }
 
 void VcsPluginHelper::add()
 {
+    Q_D(VcsPluginHelper);
+
     EXECUTE_VCS_METHOD(add);
 }
 
 void VcsPluginHelper::commit()
 {
+    Q_D(VcsPluginHelper);
+
     Q_ASSERT(!d->ctxUrls.isEmpty());
     ICore::self()->documentController()->saveAllDocuments();
 
     QUrl url = d->ctxUrls.first();
 
     // We start the commit UI no matter whether there is real differences, as it can also be used to commit untracked files
-    VCSCommitDiffPatchSource* patchSource = new VCSCommitDiffPatchSource(new VCSStandardDiffUpdater(d->vcs, url));
+    auto* patchSource = new VCSCommitDiffPatchSource(new VCSStandardDiffUpdater(d->vcs, url));
 
     bool ret = showVcsDiff(patchSource);
 
@@ -487,7 +541,9 @@ void VcsPluginHelper::commit()
 
 void VcsPluginHelper::push()
 {
-    foreach(const QUrl &url, d->ctxUrls) {
+    Q_D(VcsPluginHelper);
+
+    for (const QUrl& url : qAsConst(d->ctxUrls)) {
         VcsJob* job = d->plugin->extension<IDistributedVersionControl>()->push(url, VcsLocation());
         ICore::self()->runController()->registerJob(job);
     }
@@ -495,7 +551,9 @@ void VcsPluginHelper::push()
 
 void VcsPluginHelper::pull()
 {
-    foreach(const QUrl &url, d->ctxUrls) {
+    Q_D(VcsPluginHelper);
+
+    for (const QUrl& url : qAsConst(d->ctxUrls)) {
         VcsJob* job = d->plugin->extension<IDistributedVersionControl>()->pull(VcsLocation(), url);
         ICore::self()->runController()->registerJob(job);
     }
