@@ -299,7 +299,7 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
             metaDataFileNames << templateEntry->name();
 
             // check if a preview file is to be ignored
-            const KArchiveFile *templateFile = static_cast<const KArchiveFile*>(templateEntry);
+            const auto *templateFile = static_cast<const KArchiveFile*>(templateEntry);
             QTemporaryDir temporaryDir;
             templateFile->copyTo(temporaryDir.path());
 
@@ -417,7 +417,7 @@ bool AppWizardPlugin::unpackArchive(const KArchiveDirectory* dir, const QString&
     const QStringList entries = dir->entries();
     qCDebug(PLUGIN_APPWIZARD) << "entries:" << entries.join(QLatin1Char(','));
 
-    //This extra tempdir is needed just for the files files have special names,
+    //This extra tempdir is needed just for the files that have special names,
     //which may contain macros also files contain content with macros. So the
     //easiest way to extract the files from the archive and then rename them
     //and replace the macros is to use a tempdir and copy the file (and
@@ -434,7 +434,7 @@ bool AppWizardPlugin::unpackArchive(const KArchiveDirectory* dir, const QString&
 
         const auto entry = dir->entry(entryName);
         if (entry->isDirectory()) {
-            const KArchiveDirectory* subdir = static_cast<const KArchiveDirectory*>(entry);
+            const auto* subdir = static_cast<const KArchiveDirectory*>(entry);
             const QString newdest = dest + QLatin1Char('/') + KMacroExpander::expandMacros(subdir->name(), m_variables);
             if( !QFileInfo::exists( newdest ) )
             {
@@ -443,7 +443,7 @@ bool AppWizardPlugin::unpackArchive(const KArchiveDirectory* dir, const QString&
             ret |= unpackArchive(subdir, newdest);
         }
         else if (entry->isFile()) {
-            const KArchiveFile* file = static_cast<const KArchiveFile*>(entry);
+            const auto* file = static_cast<const KArchiveFile*>(entry);
             file->copyTo(tdir.path());
             const QString destName = dest + QLatin1Char('/') + file->name();
             if (!copyFileAndExpandMacros(QDir::cleanPath(tdir.path() + QLatin1Char('/') + file->name()),
