@@ -43,10 +43,11 @@
 #include <language/duchain/types/pointertype.h>
 #include <language/duchain/types/typealiastype.h>
 #include <language/duchain/types/typeutils.h>
+#include <language/duchain/stringhelpers.h>
 #include <language/codecompletion/codecompletionmodel.h>
 #include <language/codecompletion/normaldeclarationcompletionitem.h>
+#include <language/codegen/documentchangeset.h>
 #include <util/foregroundlock.h>
-#include <qtcompat_p.h>
 #include <custom-definesandincludes/idefinesandincludesmanager.h>
 #include <project/projectmodel.h>
 
@@ -59,6 +60,7 @@
 #include "../duchain/navigationwidget.h"
 #include "../clangsettings/clangsettingsmanager.h"
 
+#include <algorithm>
 #include <functional>
 #include <memory>
 
@@ -196,7 +198,14 @@ public:
             replacement.append(QLatin1Char(';'));
         }
 
-        view->document()->replaceText(word, replacement);
+        DocumentChange overrideChange(IndexedString(view->document()->url()),
+                                            word,
+                                            QString{},
+                                            replacement);
+        overrideChange.m_ignoreOldText = true;
+        DocumentChangeSet changes;
+        changes.addChange(overrideChange);
+        changes.applyAllChanges();
     }
 
 private:
@@ -364,7 +373,36 @@ public:
 
     void execute(KTextEditor::View* view, const KTextEditor::Range& word) override
     {
-        view->document()->replaceText(word, m_replacement);
+        auto* const document = view->document();
+
+        DocumentChangeSet changes;
+        KTextEditor::Cursor rangeStart = word.start();
+
+        // try and replace leading typed text that match the proposed implementation
+        const QString leading = document->line(word.end().line()).left(word.end().column());
+        const QString leadingNoSpace = removeWhitespace(leading);
+        if (!leadingNoSpace.isEmpty() && (removeWhitespace(m_display).startsWith(leadingNoSpace)
+            || removeWhitespace(m_replacement).startsWith(leadingNoSpace))) {
+            const int removeSize = leading.end() - std::find_if_not(leading.begin(), leading.end(),
+                                        [](QChar c){ return c.isSpace(); });
+            rangeStart = {word.end().line(), word.end().column() - removeSize};
+        }
+
+        DocumentChange change(IndexedString(view->document()->url()),
+                              KTextEditor::Range(rangeStart, word.end()),
+                              QString(),
+                              m_replacement);
+        change.m_ignoreOldText = true;
+        changes.addChange(change);
+        changes.applyAllChanges();
+
+        // Place cursor after the opening brace
+        // arbitrarily chose 4, as it would accomodate the template and return types on their own line
+        const auto searchRange = KTextEditor::Range(rangeStart, rangeStart.line() + 4, 0);
+        const auto results = view->document()->searchText(searchRange, QStringLiteral("{"));
+        if (!results.isEmpty()) {
+            view->setCursorPosition(results.first().end());
+        }
     }
 };
 
@@ -488,7 +526,7 @@ QString& elideStringRight(QString& str, int length)
 /**
  * @return Value suited for @ref CodeCompletionModel::MatchQuality in the range [0.0, 10.0] (the higher the better)
  *
- * See http://clang.llvm.org/doxygen/CodeCompleteConsumer_8h_source.html for list of priorities
+ * See https://clang.llvm.org/doxygen/CodeCompleteConsumer_8h_source.html for list of priorities
  * They (currently) have a range from [-3, 80] (the lower, the better)
  */
 int codeCompletionPriorityToMatchQuality(unsigned int completionPriority)
@@ -759,7 +797,7 @@ private:
     }
 
     // Declaration and it's context
-    typedef QPair<Declaration*, Declaration*> DeclarationContext;
+    using DeclarationContext = QPair<Declaration*, Declaration*>;
 
     /// Types of declarations that look-ahead completion items can have
     QSet<IndexedType> matchedTypes;
@@ -1149,6 +1187,19 @@ QList<CompletionTreeItemPointer> ClangCodeCompletionContext::completionItems(boo
 
             auto found = findDeclaration(qid, ctx, m_position, isOverloadCandidate ? overloadsHandled : handled);
 
+            if (found && found->type<FunctionType>() == nullptr && parent.isEmpty() && !resultType.isEmpty()) {
+                // workaround: for multiple nameless structs with the same member.
+                // Check the type of the member to have at least a higher probability.
+                auto typeCheckedDeclaration = found;
+                while (typeCheckedDeclaration != nullptr && typeCheckedDeclaration->abstractType() != nullptr) {
+                    if (typeCheckedDeclaration->abstractType()->toString() == resultType) {
+                        found = typeCheckedDeclaration;
+                        break;
+                    }
+                    typeCheckedDeclaration = findDeclaration(qid, ctx, m_position, isOverloadCandidate ? overloadsHandled : handled);
+                }
+            }
+
             CompletionTreeItemPointer item;
             if (found) {
                 // TODO: Bug in Clang: protected members from base classes not accessible in derived classes.
