@@ -64,7 +64,7 @@ QString CMakeFunctionArgument::unescapeValue(const QString& value)
         last=i+2;
     }
     newValue+=value.midRef(last, value.size());
-//     qCDebug(CMAKE) << "escapiiiiiiiiing" << value << newValue;
+//     qCDebug(CMAKE) << "escaping" << value << newValue;
     return newValue;
 }
 
@@ -188,6 +188,7 @@ bool CMakeListsParser::readCMakeFunction(cmListFileLexer *lexer, CMakeFunctionDe
                 func.arguments << CMakeFunctionArgument( QString::fromLocal8Bit(token->text, token->length), false, token->line, token->column );
                 break;
             case cmListFileLexer_Token_Identifier:
+            case cmListFileLexer_Token_ArgumentBracket:
             case cmListFileLexer_Token_ArgumentUnquoted:
                 func.arguments << CMakeFunctionArgument( QString::fromLocal8Bit(token->text, token->length), false, token->line, token->column );
                 break;
