@@ -188,7 +188,8 @@ Path::List GccLikeCompiler::includes(Utils::LanguageType type, const QString& ar
     Status mode = Initial;
 
     const auto output = QString::fromLocal8Bit( proc.readAllStandardOutput() );
-    foreach (const auto& line, output.splitRef(QLatin1Char('\n'))) {
+    const auto lines = output.splitRef(QLatin1Char('\n'));
+    for (const auto& line : lines) {
         switch ( mode ) {
             case Initial:
                 if ( line.indexOf( QLatin1String("#include \"...\"") ) != -1 ) {
