@@ -53,8 +53,9 @@ DockerPlugin::DockerPlugin(QObject *parent, const QVariantList & /*args*/)
     setXMLFile( QStringLiteral("kdevdockerplugin.rc") );
     connect(ICore::self()->runtimeController(), &IRuntimeController::currentRuntimeChanged, this, &DockerPlugin::runtimeChanged);
 
-    QProcess* process = new QProcess(this);
-    connect(process, static_cast<void(QProcess::*)(int,QProcess::ExitStatus)>(&QProcess::finished), this, &DockerPlugin::imagesListFinished);
+    auto* process = new QProcess(this);
+    connect(process, QOverload<int,QProcess::ExitStatus>::of(&QProcess::finished),
+            this, &DockerPlugin::imagesListFinished);
     process->start(QStringLiteral("docker"), {QStringLiteral("images"), QStringLiteral("--filter"), QStringLiteral("dangling=false"), QStringLiteral("--format"), QStringLiteral("{{.Repository}}:{{.Tag}}\t{{.ID}}")}, QIODevice::ReadOnly);
 
     DockerRuntime::s_settings = m_settings.data();
@@ -70,7 +71,7 @@ void DockerPlugin::imagesListFinished(int code)
     if (code != 0)
         return;
 
-    QProcess* process = qobject_cast<QProcess*>(sender());
+    auto* process = qobject_cast<QProcess*>(sender());
     Q_ASSERT(process);
     QTextStream stream(process);
     while(!stream.atEnd()) {
@@ -100,11 +101,12 @@ KDevelop::ContextMenuExtension DockerPlugin::contextMenuExtension(KDevelop::Cont
     QList<QUrl> urls;
 
     if ( context->type() == KDevelop::Context::FileContext ) {
-        KDevelop::FileContext* filectx = static_cast<KDevelop::FileContext*>(context);
+        auto* filectx = static_cast<KDevelop::FileContext*>(context);
         urls = filectx->urls();
     } else if ( context->type() == KDevelop::Context::ProjectItemContext ) {
-        KDevelop::ProjectItemContext* projctx = static_cast<KDevelop::ProjectItemContext*>(context);
-        foreach( KDevelop::ProjectBaseItem* item, projctx->items() ) {
+        auto* projctx = static_cast<KDevelop::ProjectItemContext*>(context);
+        const auto items = projctx->items();
+        for (KDevelop::ProjectBaseItem* item : items) {
             if ( item->file() ) {
                 urls << item->path().toUrl();
             }
@@ -121,7 +123,7 @@ KDevelop::ContextMenuExtension DockerPlugin::contextMenuExtension(KDevelop::Cont
 
     if ( !urls.isEmpty() ) {
         KDevelop::ContextMenuExtension ext;
-        foreach(const QUrl &url, urls) {
+        for (const QUrl& url : qAsConst(urls)) {
             const KDevelop::Path file(url);
 
             auto action = new QAction(QIcon::fromTheme(QStringLiteral("text-dockerfile")), i18n("docker build '%1'", file.path()), parent);
