@@ -17,14 +17,10 @@
   Boston, MA 02110-1301, USA.
 */
 
-#ifndef KDEVDOCUMENTVIEW_PART_H
-#define KDEVDOCUMENTVIEW_PART_H
-
-#include <QtCore/QHash>
-#include <QtCore/QPointer>
+#ifndef KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEWPLUGIN_H
+#define KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEWPLUGIN_H
 
 #include <interfaces/iplugin.h>
-#include <interfaces/idocumentcontroller.h>
 
 class KDevDocumentViewPluginFactory;
 
@@ -41,8 +37,8 @@ public:
 
 public:
     KDevDocumentViewPlugin( QObject *parent, const QVariantList& args );
-    virtual ~KDevDocumentViewPlugin();
-    virtual void unload();
+    ~KDevDocumentViewPlugin() override;
+    void unload() override;
 
 private:
     KDevDocumentViewPluginFactory* factory;
