@@ -112,7 +112,7 @@ NativeAppConfigPage::NativeAppConfigPage( QWidget* parent )
     configureEnvironment->setSelectionWidget(environment);
 
     //connect signals to changed signal
-    connect( projectTarget, static_cast<void(ProjectTargetsComboBox::*)(const QString&)>(&ProjectTargetsComboBox::currentIndexChanged), this, &NativeAppConfigPage::changed );
+    connect( projectTarget, &QComboBox::currentTextChanged, this, &NativeAppConfigPage::changed );
     connect( projectTargetRadio, &QRadioButton::toggled, this, &NativeAppConfigPage::changed );
     connect( executableRadio, &QRadioButton::toggled, this, &NativeAppConfigPage::changed );
     connect( executablePath->lineEdit(), &KLineEdit::textEdited, this, &NativeAppConfigPage::changed );
@@ -121,11 +121,11 @@ NativeAppConfigPage::NativeAppConfigPage( QWidget* parent )
     connect( workingDirectory, &KUrlRequester::urlSelected, this, &NativeAppConfigPage::changed );
     connect( workingDirectory->lineEdit(), &KLineEdit::textEdited, this, &NativeAppConfigPage::changed );
     connect( environment, &EnvironmentSelectionWidget::currentProfileChanged, this, &NativeAppConfigPage::changed );
-    connect( dependencyAction, static_cast<void(KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &NativeAppConfigPage::changed );
+    connect( dependencyAction, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &NativeAppConfigPage::changed );
     connect( runInTerminal, &QCheckBox::toggled, this, &NativeAppConfigPage::changed );
     connect( terminal, &KComboBox::editTextChanged, this, &NativeAppConfigPage::changed );
-    connect( terminal, static_cast<void(KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &NativeAppConfigPage::changed );
-    connect( dependencyAction, static_cast<void(KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &NativeAppConfigPage::activateDeps );
+    connect( terminal, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &NativeAppConfigPage::changed );
+    connect( dependencyAction, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &NativeAppConfigPage::activateDeps );
     connect( dependencies, &DependenciesWidget::changed, this, &NativeAppConfigPage::changed );
 }
 
@@ -188,7 +188,7 @@ KJob* NativeAppLauncher::start(const QString& launchMode, KDevelop::ILaunchConfi
     }
     if( launchMode == QLatin1String("execute") )
     {
-        IExecutePlugin* iface = KDevelop::ICore::self()->pluginController()->pluginForExtension(QStringLiteral("org.kdevelop.IExecutePlugin"), QStringLiteral("kdevexecute"))->extension<IExecutePlugin>();
+        auto* iface = KDevelop::ICore::self()->pluginController()->pluginForExtension(QStringLiteral("org.kdevelop.IExecutePlugin"), QStringLiteral("kdevexecute"))->extension<IExecutePlugin>();
         Q_ASSERT(iface);
         KJob* depjob = iface->dependencyJob( cfg );
         QList<KJob*> l;
@@ -287,8 +287,10 @@ void NativeAppConfigType::configureLaunchFromCmdLineArguments ( KConfigGroup cfg
 QList<KDevelop::ProjectTargetItem*> targetsInFolder(KDevelop::ProjectFolderItem* folder)
 {
     QList<KDevelop::ProjectTargetItem*> ret;
-    foreach(KDevelop::ProjectFolderItem* f, folder->folderList())
+    const auto folders = folder->folderList();
+    for (KDevelop::ProjectFolderItem* f : folders) {
         ret += targetsInFolder(f);
+    }
 
     ret += folder->targetList();
     return ret;
@@ -320,7 +322,7 @@ QMenu* NativeAppConfigType::launcherSuggestions()
                 if(target->executable()) {
                     QStringList path = model->pathFromIndex(target->index());
                     if(!path.isEmpty()){
-                        QAction* act = new QAction(projectMenu);
+                        auto* act = new QAction(projectMenu);
                         act->setData(KDevelop::joinWithEscaping(path, QLatin1Char('/'), QLatin1Char('\\')));
                         act->setProperty("name", target->text());
                         path.removeFirst();
@@ -334,12 +336,13 @@ QMenu* NativeAppConfigType::launcherSuggestions()
 
             QList<QAction*> separateActions;
             QList<QMenu*> submenus;
-            foreach(KDevelop::ProjectBaseItem* folder, targetsContainer.keys()) {
-                QList<QAction*> actions = targetsContainer.value(folder);
+            for (auto it = targetsContainer.constBegin(), end = targetsContainer.constEnd(); it != end; ++it) {
+                KDevelop::ProjectBaseItem* folder = it.key();
+                QList<QAction*> actions = it.value();
                 if(actions.size()==1 || !folder->parent()) {
                     separateActions.append(actions);
                 } else {
-                    foreach(QAction* a, actions) {
+                    for (QAction* a : qAsConst(actions)) {
                         a->setText(a->property("name").toString());
                     }
                     QStringList path = model->pathFromIndex(folder->index());
@@ -352,8 +355,9 @@ QMenu* NativeAppConfigType::launcherSuggestions()
             }
             std::sort(separateActions.begin(), separateActions.end(), actionLess);
             std::sort(submenus.begin(), submenus.end(), menuLess);
-            foreach(QMenu* m, submenus)
+            for (QMenu* m : qAsConst(submenus)) {
                 projectMenu->addMenu(m);
+            }
             projectMenu->addActions(separateActions);
 
             projectMenu->setEnabled(!projectMenu->isEmpty());
@@ -365,7 +369,7 @@ QMenu* NativeAppConfigType::launcherSuggestions()
 
 void NativeAppConfigType::suggestionTriggered()
 {
-    QAction* action = qobject_cast<QAction*>(sender());
+    auto* action = qobject_cast<QAction*>(sender());
     KDevelop::ProjectModel* model = KDevelop::ICore::self()->projectController()->projectModel();
     KDevelop::ProjectTargetItem* pitem = dynamic_cast<KDevelop::ProjectTargetItem*>(itemForPath(KDevelop::splitWithEscaping(action->data().toString(), QLatin1Char('/'), QLatin1Char('\\')), model));
     if(pitem) {
