@@ -147,13 +147,14 @@ void OverridesPage::addBaseClasses(const QList<DeclarationPointer>& directBases,
         }
 
         //For this internal context get all the function declarations inside the class
-        foreach (Declaration * childDeclaration, context->localDeclarations()) {
-            if (AbstractFunctionDeclaration * func = dynamic_cast<AbstractFunctionDeclaration*>(childDeclaration))
+        const auto localDeclarations = context->localDeclarations();
+        for (Declaration* childDeclaration : localDeclarations) {
+            if (auto * func = dynamic_cast<AbstractFunctionDeclaration*>(childDeclaration))
             {
                 if (func->isVirtual())
                 {
                     // Its a virtual function, add it to the list unless it's a destructor
-                    ClassFunctionDeclaration* cFunc = dynamic_cast<ClassFunctionDeclaration*>(childDeclaration);
+                    auto* cFunc = dynamic_cast<ClassFunctionDeclaration*>(childDeclaration);
                     if (cFunc && !cFunc->isDestructor())
                     {
                         addPotentialOverride(classItem, DeclarationPointer(childDeclaration));
@@ -162,7 +163,7 @@ void OverridesPage::addBaseClasses(const QList<DeclarationPointer>& directBases,
                 else if (directBases.contains(baseClass))
                 {
                     // add ctors of direct parents
-                    ClassFunctionDeclaration* cFunc = dynamic_cast<ClassFunctionDeclaration*>(childDeclaration);
+                    auto* cFunc = dynamic_cast<ClassFunctionDeclaration*>(childDeclaration);
                     if (cFunc && cFunc->isConstructor())
                     {
                         addPotentialOverride(classItem, DeclarationPointer(childDeclaration));
@@ -178,7 +179,7 @@ void OverridesPage::addBaseClasses(const QList<DeclarationPointer>& directBases,
 
 void OverridesPage::addPotentialOverride(QTreeWidgetItem* classItem, const DeclarationPointer& childDeclaration)
 {
-    ClassFunctionDeclaration* function = dynamic_cast<ClassFunctionDeclaration*>(childDeclaration.data());
+    auto* function = dynamic_cast<ClassFunctionDeclaration*>(childDeclaration.data());
     if (!function) {
         qCDebug(PLUGIN_FILETEMPLATES) << "Declaration is not a function:" << childDeclaration->identifier().toString();
         return;
@@ -190,10 +191,10 @@ void OverridesPage::addPotentialOverride(QTreeWidgetItem* classItem, const Decla
     }
 
     qCDebug(PLUGIN_FILETEMPLATES) << childDeclaration->toString();
-    if (d->overriddenFunctions.contains(childDeclaration->identifier()))
-    {
-        foreach (const DeclarationPointer& decl, d->overriddenFunctions.values(childDeclaration->identifier()))
-        {
+    auto overridenFunctionIt = d->overriddenFunctions.constFind(childDeclaration->identifier());
+    if (overridenFunctionIt != d->overriddenFunctions.constEnd()) {
+        for (; overridenFunctionIt != d->overriddenFunctions.constEnd(); ++overridenFunctionIt) {
+            const DeclarationPointer& decl = *overridenFunctionIt;
             if (decl->indexedType() == childDeclaration->indexedType())
             {
                 qCDebug(PLUGIN_FILETEMPLATES) << "Declaration is already shown";
