@@ -103,7 +103,7 @@ PatchReviewToolView::PatchReviewToolView( QWidget* parent, PatchReviewPlugin* pl
     connect( plugin, &PatchReviewPlugin::startingNewReview, this, &PatchReviewToolView::startingNewReview );
     connect( ICore::self()->documentController(), &IDocumentController::documentActivated, this, &PatchReviewToolView::documentActivated );
 
-    Sublime::MainWindow* w = dynamic_cast<Sublime::MainWindow*>( ICore::self()->uiController()->activeMainWindow() );
+    auto* w = qobject_cast<Sublime::MainWindow*>(ICore::self()->uiController()->activeMainWindow());
     connect(w, &Sublime::MainWindow::areaChanged, m_plugin, &PatchReviewPlugin::areaChanged);
 
     showEditDialog();
@@ -154,7 +154,7 @@ LocalPatchSource* PatchReviewToolView::GetLocalPatchSource() {
 
     if ( !ips )
         return nullptr;
-    return dynamic_cast<LocalPatchSource*>( ips.data() );
+    return qobject_cast<LocalPatchSource*>(ips.data());
 }
 
 void PatchReviewToolView::fillEditFromPatch() {
@@ -278,8 +278,7 @@ void PatchReviewToolView::customContextMenuRequested(const QPoint& pos)
     }
 
     QList<QAction*> vcsActions;
-    foreach( const ContextMenuExtension& ext, extensions )
-    {
+    for (const ContextMenuExtension& ext : qAsConst(extensions)) {
         vcsActions += ext.actions(ContextMenuExtension::VcsGroup);
     }
 
@@ -365,8 +364,8 @@ void PatchReviewToolView::open( const QUrl& url, bool activate ) const
     qCDebug(PLUGIN_PATCHREVIEW) << "activating url" << url;
     // If the document is already open in this area, just re-activate it
     if(KDevelop::IDocument* doc = ICore::self()->documentController()->documentForUrl(url)) {
-        foreach(Sublime::View* view, ICore::self()->uiController()->activeArea()->views())
-        {
+        const auto views = ICore::self()->uiController()->activeArea()->views();
+        for (Sublime::View* view : views) {
             if(view->document() == dynamic_cast<Sublime::Document*>(doc))
             {
                 if (activate) {
@@ -426,8 +425,8 @@ void PatchReviewToolView::fileItemChanged( QStandardItem* item )
     {   // The file was deselected, so eventually close it
         if(doc && doc->state() == IDocument::Clean)
         {
-            foreach(Sublime::View* view, ICore::self()->uiController()->activeArea()->views())
-            {
+            const auto views = ICore::self()->uiController()->activeArea()->views();
+            for (Sublime::View* view : views) {
                 if(view->document() == dynamic_cast<Sublime::Document*>(doc))
                 {
                     ICore::self()->uiController()->activeArea()->closeView(view);
@@ -563,7 +562,7 @@ void PatchReviewToolView::runTests()
     m_editPatch.testProgressBar->setValue(0);
     m_editPatch.testProgressBar->show();
 
-    ProjectTestJob* job = new ProjectTestJob(project, this);
+    auto* job = new ProjectTestJob(project, this);
     connect(job, &ProjectTestJob::finished, this, &PatchReviewToolView::testJobResult);
     connect(job, SIGNAL(percent(KJob*,ulong)), this, SLOT(testJobPercent(KJob*,ulong)));
     ICore::self()->runController()->registerJob(job);
@@ -577,7 +576,7 @@ void PatchReviewToolView::testJobPercent(KJob* job, ulong percent)
 
 void PatchReviewToolView::testJobResult(KJob* job)
 {
-    ProjectTestJob* testJob = qobject_cast<ProjectTestJob*>(job);
+    auto* testJob = qobject_cast<ProjectTestJob*>(job);
     if (!testJob) {
         return;
     }
